[![Codacy Badge](https://api.codacy.com/project/badge/Grade/bca9ac5149b34ac7bb8ffdb42ecd857c)](https://www.codacy.com/app/socisomer/Sallust?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=socisomer/Sallust&amp;utm_campaign=Badge_Grade)
# Sallust
![Contribution guidelines for this project](GUI/img/Apyno_logo_big.png)

Sallust is a modern, open source testing support application. it helps track tests cases
